@@ -44,6 +44,8 @@ class Keap:
 
     @property
     def XML(self):
+        if self.token.is_expired:
+            self.refresh_access_token()
         if not self.xml_client:
             self.xml_client = XML(self)
         return self.xml_client
