@@ -4,7 +4,9 @@ from enum import Enum
 
 import requests
 
+from keap import KeapToken, Keap
 from keap.REST.models import BaseDataModel
+from keap.exceptions import KeapUnauthorizedException, KeapForbiddenException, KeapTokenExpiredException
 
 
 class RecordNotFoundError(Exception):
@@ -16,12 +18,13 @@ class BaseService:
     api_url: str = None
     _service = None
     client = None
+    keap: Keap
 
     def __init__(self, keap):
         self.keap = keap
 
     @property
-    def token(self):
+    def token(self) -> KeapToken:
         return self.keap.token
 
     def _get(self, path: str, params: dict = None):
@@ -63,13 +66,11 @@ class BaseService:
         return data
 
     def restful_request(self, method: str, path: str, data: dict = None, params: dict = None):
-        # TODO: Implement Token Expired Exception
         if data is None:
             data = dict()
         if params is None:
             params = dict()
         params["access_token"] = self.token.access_token
-
         headers = {
             'Content-Type': 'application/json'
         }
@@ -85,13 +86,20 @@ class BaseService:
             response = requests.request(method, url, headers=headers, data=json.dumps(data), params=params)
 
         # TODO: Implement rate limiting here. response.headers contains the Apigee rate limiting info.
-        # TODO: need to handle non-json responses here. DELETE returns an empty body.
-        if response.status_code == 404:
-            raise RecordNotFoundError()
         if response.status_code == 204:  # No Content
             return True
+        response_json = response.json()
+        if type(response_json) is list:
+            return response_json
+        fault = response_json.get('fault', {}).get('faultstring', 'Error')
+        if response.status_code == 401:  # Unauthorized
+            raise KeapUnauthorizedException(fault)
+        if response.status_code == 403:  # Forbidden
+            raise KeapForbiddenException(fault)
+        if response.status_code == 404:  # Not Found
+            raise RecordNotFoundError(fault)
 
-        return response.json()
+        return response_json
 
     @property
     def service(self):
