@@ -21,3 +21,10 @@ class EmailService(CreateMixin, DeleteMixin, ListMixin, RetrieveMixin):
 
     def update_email_address(self, email: str, opted_in: bool = True, reason: str = "Opted in via API"):
         self._put(f"emailAddresses/{email}", data={'opted_in': opted_in, 'reason': reason})
+
+    def list_emails_by_contact_id(self, contact_id: int):
+        params = locals()
+        return self._get(f"{self.api_url}", params=params)
+
+    def get_email(self, id:int):
+        return self._get(f"{self.api_url}/{id}")
